# Glean SDK

The `Glean SDK` is a modern approach for a Telemetry library and is part of the [Glean project][project-overview].

## Documentation

The full Glean SDK documentation is available online:

## [The Glean SDK Book][book]

## License

    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/

[project-overview]: https://docs.telemetry.mozilla.org/concepts/glean/glean.html
[book]: https://mozilla.github.io/glean/
